@@ -29,11 +29,6 @@ WId MockClient::decorationId() const
     return 0;
 }
 
-int MockClient::desktop() const
-{
-    return 1;
-}
-
 int MockClient::height() const
 {
     return m_height;
@@ -293,3 +288,5 @@ void MockClient::showApplicationMenu(int actionId)
 {
     Q_UNUSED(actionId)
 }
+
+#include "moc_mockclient.cpp"
