@@ -16,14 +16,14 @@ KDecoration2::BorderSize MockSettings::borderSize() const
     return KDecoration2::BorderSize::Normal;
 }
 
-QVector< KDecoration2::DecorationButtonType > MockSettings::decorationButtonsLeft() const
+QList<KDecoration2::DecorationButtonType> MockSettings::decorationButtonsLeft() const
 {
-    return QVector<KDecoration2::DecorationButtonType>();
+    return QList<KDecoration2::DecorationButtonType>();
 }
 
-QVector< KDecoration2::DecorationButtonType > MockSettings::decorationButtonsRight() const
+QList<KDecoration2::DecorationButtonType> MockSettings::decorationButtonsRight() const
 {
-    return QVector<KDecoration2::DecorationButtonType>();
+    return QList<KDecoration2::DecorationButtonType>();
 }
 
 bool MockSettings::isAlphaChannelSupported() const
@@ -47,7 +47,7 @@ void MockSettings::setOnAllDesktopsAvailabe(bool set)
         return;
     }
     m_onAllDesktopsAvailable = set;
-    emit decorationSettings()->onAllDesktopsAvailableChanged(m_onAllDesktopsAvailable);
+    Q_EMIT decorationSettings()->onAllDesktopsAvailableChanged(m_onAllDesktopsAvailable);
 }
 
 void MockSettings::setCloseOnDoubleClickOnMenu(bool set)
@@ -56,5 +56,5 @@ void MockSettings::setCloseOnDoubleClickOnMenu(bool set)
         return;
     }
     m_closeDoubleClickOnMenu = set;
-    emit decorationSettings()->closeOnDoubleClickOnMenuChanged(m_closeDoubleClickOnMenu);
+    Q_EMIT decorationSettings()->closeOnDoubleClickOnMenuChanged(m_closeDoubleClickOnMenu);
 }
